#line 2 "sequence/fastal.c"

#line 4 "sequence/fastal.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer fasta_create_buffer
#define yy_delete_buffer fasta_delete_buffer
#define yy_flex_debug fasta_flex_debug
#define yy_init_buffer fasta_init_buffer
#define yy_flush_buffer fasta_flush_buffer
#define yy_load_buffer_state fasta_load_buffer_state
#define yy_switch_to_buffer fasta_switch_to_buffer
#define yyin fastain
#define yyleng fastaleng
#define yylex fastalex
#define yylineno fastalineno
#define yyout fastaout
#define yyrestart fastarestart
#define yytext fastatext
#define yywrap fastawrap
#define yyalloc fastaalloc
#define yyrealloc fastarealloc
#define yyfree fastafree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE fastarestart(fastain  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int fastaleng;

extern FILE *fastain, *fastaout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up fastatext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up fastatext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via fastarestart()), so that the user can continue scanning by
	 * just pointing fastain at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when fastatext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int fastaleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow fastawrap()'s to do buffer switches
 * instead of setting up a fresh fastain.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void fastarestart (FILE *input_file  );
void fasta_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE fasta_create_buffer (FILE *file,int size  );
void fasta_delete_buffer (YY_BUFFER_STATE b  );
void fasta_flush_buffer (YY_BUFFER_STATE b  );
void fastapush_buffer_state (YY_BUFFER_STATE new_buffer  );
void fastapop_buffer_state (void );

static void fastaensure_buffer_stack (void );
static void fasta_load_buffer_state (void );
static void fasta_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER fasta_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE fasta_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE fasta_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE fasta_scan_bytes (yyconst char *bytes,int len  );

void *fastaalloc (yy_size_t  );
void *fastarealloc (void *,yy_size_t  );
void fastafree (void *  );

#define yy_new_buffer fasta_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        fastaensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            fasta_create_buffer(fastain,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        fastaensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            fasta_create_buffer(fastain,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define fastawrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *fastain = (FILE *) 0, *fastaout = (FILE *) 0;

typedef int yy_state_type;

extern int fastalineno;

int fastalineno = 1;

extern char *fastatext;
#define yytext_ptr fastatext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up fastatext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	fastaleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 16
#define YY_END_OF_BUFFER 17
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[430] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   17,   15,
       14,   15,    1,    2,    4,    6,    5,    4,    4,    4,
        7,    8,   13,   10,   11,    9,    9,    0,    1,    4,
        5,    4,    7,   12,    9,    9,    4,    4,    7,    9,
        9,    4,    4,    7,    9,    9,    4,    4,    3,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,

        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,

        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,

        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,

        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    4,    4,    7,
        9,    9,    4,    4,    7,    9,    9,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    1,    6,    1,    1,    1,    7,    1,
        8,    1,    1,    1,    1,    1,    1,    1,    9,    1,
        1,   10,    1,    1,   11,   11,   12,   13,   11,   14,
       11,   11,   11,   11,   11,   12,   11,   15,   11,   14,
       11,   13,   11,   11,   11,   11,   11,   11,   11,   11,
        1,    1,    1,    1,    1,    1,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,    1,    1,    1,   16,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[17] =
    {   0,
        1,    2,    3,    4,    5,    5,    1,    1,    1,    1,
        5,    5,    5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[749] =
    {   0,
      944,    0,    8,   21,  943,  938,   36,    0,  937, 1564,
     1564,  929, 1564, 1564,    0, 1564,  927,  914,  915,    0,
        0, 1564, 1564, 1564,  907,    0,    3,  913, 1564,    0,
      907,  898,    0, 1564,   11,   12,    0,    0,    0,   14,
       47,    0,  899,    0,   48,   49,    0,  898, 1564,    0,
       50,   51,    0,  893,    0,   52,   53,    0,  889,    0,
       54,   55,    0,  884,    0,   56,   67,    0,  883,    0,
       68,   69,    0,  878,    0,   70,   71,    0,  874,    0,
       72,   73,    0,  869,    0,   74,   75,    0,  868,    0,
       76,   87,    0,  863,    0,   88,   89,    0,  859,    0,

       90,   91,    0,  854,    0,   92,   93,    0,  853,    0,
       94,   95,    0,  848,    0,   96,  107,    0,  844,    0,
      108,  109,    0,  839,    0,  110,  111,    0,  838,    0,
      112,  113,    0,  833,    0,  114,  115,    0,  829,    0,
      116,  127,    0,  824,    0,  128,  129,    0,  823,    0,
      130,  131,    0,  818,    0,  132,  133,    0,  814,    0,
      134,  135,    0,  809,    0,  136,  147,    0,  808,    0,
      148,  149,    0,  803,    0,  150,  151,    0,  799,    0,
      152,  153,    0,  794,    0,  154,  155,    0,  793,    0,
      156,  167,    0,  788,    0,  168,  169,    0,  784,    0,

      170,  171,    0,  779,    0,  172,  173,    0,  778,    0,
      174,  175,    0,  773,    0,  176,  187,    0,  769,    0,
      188,  189,    0,  764,    0,  190,  191,    0,  763,    0,
      192,  193,    0,  758,    0,  194,  195,    0,  754,    0,
      196,  207,    0,  749,    0,  208,  209,    0,  748,    0,
      210,  211,    0,  743,    0,  212,  213,    0,  739,    0,
      214,  215,    0,  734,    0,  216,  227,    0,  733,    0,
      228,  229,    0,  728,    0,  230,  231,    0,  724,    0,
      232,  233,    0,  719,    0,  234,  235,    0,  718,    0,
      236,  247,    0,  713,    0,  248,  249,    0,  709,    0,

      250,  251,    0,  704,    0,  252,  253,    0,  703,    0,
      254,  255,    0,  698,    0,  256,  267,    0,  694,    0,
      268,  269,    0,  689,    0,  270,  271,    0,  688,    0,
      272,  273,    0,  683,    0,  274,  275,    0,  679,    0,
      276,  287,    0,  674,    0,  288,  289,    0,  673,    0,
      290,  291,    0,  668,    0,  292,  293,    0,  664,    0,
      294,  295,    0,  659,    0,  296,  307,    0,  658,    0,
      308,  309,    0,  653,    0,  310,  311,    0,  649,    0,
      312,  313,    0,  644,    0,  314,  315,    0,  643,    0,
      316,  327,    0,  638,    0,  328,  329,    0,  634,    0,

      330,  331,    0,  629,    0,  332,  333,    0,  628,    0,
      334,  335,    0,  623,    0,  336,  347,    0,  619,    0,
      348,  349, 1564,  614, 1564, 1564, 1564,  613, 1564,  365,
      370,  375,  379,  383,  388,  606,  393,  398,  602,  403,
      408,  413,  597,  418,  423,  428,  596,  433,  438,  443,
      591,  448,  453,  458,  587,  463,  468,  473,  582,  478,
      483,  488,  581,  493,  498,  503,  576,  508,  513,  518,
      572,  523,  528,  533,  567,  538,  543,  548,  566,  553,
      558,  563,  561,  568,  573,  578,  557,  583,  588,  593,
      552,  598,  603,  608,  551,  613,  618,  623,  546,  628,

      633,  638,  542,  643,  648,  653,  537,  658,  663,  668,
      536,  673,  678,  683,  531,  688,  693,  698,  527,  703,
      708,  713,  522,  718,  723,  728,  521,  733,  738,  743,
      516,  748,  753,  758,  512,  763,  768,  773,  507,  778,
      783,  788,  506,  793,  798,  803,  501,  808,  813,  818,
      497,  823,  828,  833,  492,  838,  843,  848,  491,  853,
      858,  863,  486,  868,  873,  878,  482,  883,  888,  893,
      477,  898,  903,  908,  476,  913,  918,  923,  471,  928,
      933,  938,  467,  943,  948,  953,  462,  958,  963,  968,
      461,  973,  978,  983,  456,  988,  993,  998,  452, 1003,

     1008, 1013,  447, 1018, 1023, 1028,  446, 1033, 1038, 1043,
      441, 1048, 1053, 1058,  437, 1063, 1068, 1073,  432, 1078,
     1083, 1088,  431, 1093, 1098, 1103,  426, 1108, 1113, 1118,
      422, 1123, 1128, 1133,  417, 1138, 1143, 1148,  416, 1153,
     1158, 1163,  411, 1168, 1173, 1178,  407, 1183, 1188, 1193,
      406, 1198, 1203, 1208,  402, 1213, 1218, 1223,  401, 1228,
     1233, 1238,  396, 1243, 1248, 1253,  392, 1258, 1263, 1268,
      391, 1273, 1278, 1283,  386, 1288, 1293, 1298,  382, 1303,
     1308, 1313,  381, 1318, 1323, 1328,  357, 1333, 1338, 1343,
      356, 1348, 1353, 1358,  355, 1363, 1368, 1373,  354, 1378,

     1383, 1388,  353, 1393, 1398, 1403,  352, 1408, 1413, 1418,
      351, 1423, 1428, 1433,   28, 1438, 1443, 1448,   27, 1453,
     1458, 1463,   26, 1468, 1473, 1478,   24, 1483, 1488, 1493,
       21, 1498, 1503, 1508,   10, 1513, 1518, 1523,    9, 1528,
     1533, 1538,    8, 1543, 1548, 1553,    0, 1558
    } ;

static yyconst flex_int16_t yy_def[749] =
    {   0,
      430,  430,  431,  431,  432,  432,  429,    7,  429,  429,
      429,  433,  429,  429,  434,  429,  429,  434,  434,  434,
      435,  429,  429,  429,  429,  436,  436,  433,  429,  437,
      429,  437,  438,  429,  439,  439,  440,  441,  442,  443,
      443,  444,  445,  446,  447,  447,  448,  449,  429,  450,
      451,  451,  452,  453,  454,  455,  455,  456,  457,  458,
      459,  459,  460,  461,  462,  463,  463,  464,  465,  466,
      467,  467,  468,  469,  470,  471,  471,  472,  473,  474,
      475,  475,  476,  477,  478,  479,  479,  480,  481,  482,
      483,  483,  484,  485,  486,  487,  487,  488,  489,  490,

      491,  491,  492,  493,  494,  495,  495,  496,  497,  498,
      499,  499,  500,  501,  502,  503,  503,  504,  505,  506,
      507,  507,  508,  509,  510,  511,  511,  512,  513,  514,
      515,  515,  516,  517,  518,  519,  519,  520,  521,  522,
      523,  523,  524,  525,  526,  527,  527,  528,  529,  530,
      531,  531,  532,  533,  534,  535,  535,  536,  537,  538,
      539,  539,  540,  541,  542,  543,  543,  544,  545,  546,
      547,  547,  548,  549,  550,  551,  551,  552,  553,  554,
      555,  555,  556,  557,  558,  559,  559,  560,  561,  562,
      563,  563,  564,  565,  566,  567,  567,  568,  569,  570,

      571,  571,  572,  573,  574,  575,  575,  576,  577,  578,
      579,  579,  580,  581,  582,  583,  583,  584,  585,  586,
      587,  587,  588,  589,  590,  591,  591,  592,  593,  594,
      595,  595,  596,  597,  598,  599,  599,  600,  601,  602,
      603,  603,  604,  605,  606,  607,  607,  608,  609,  610,
      611,  611,  612,  613,  614,  615,  615,  616,  617,  618,
      619,  619,  620,  621,  622,  623,  623,  624,  625,  626,
      627,  627,  628,  629,  630,  631,  631,  632,  633,  634,
      635,  635,  636,  637,  638,  639,  639,  640,  641,  642,
      643,  643,  644,  645,  646,  647,  647,  648,  649,  650,

      651,  651,  652,  653,  654,  655,  655,  656,  657,  658,
      659,  659,  660,  661,  662,  663,  663,  664,  665,  666,
      667,  667,  668,  669,  670,  671,  671,  672,  673,  674,
      675,  675,  676,  677,  678,  679,  679,  680,  681,  682,
      683,  683,  684,  685,  686,  687,  687,  688,  689,  690,
      691,  691,  692,  693,  694,  695,  695,  696,  697,  698,
      699,  699,  700,  701,  702,  703,  703,  704,  705,  706,
      707,  707,  708,  709,  710,  711,  711,  712,  713,  714,
      715,  715,  716,  717,  718,  719,  719,  720,  721,  722,
      723,  723,  724,  725,  726,  727,  727,  728,  729,  730,

      731,  731,  732,  733,  734,  735,  735,  736,  737,  738,
      739,  739,  740,  741,  742,  743,  743,  744,  745,  746,
      747,  747,  429,  748,  429,  429,  429,  748,    0,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429
    } ;

static yyconst flex_int16_t yy_nxt[1581] =
    {   0,
      429,   12,   13,   12,  426,   36,   32,   32,   36,   14,
       16,   17,  421,  416,  411,   36,   41,   41,   36,   46,
       18,   19,   20,   16,   17,  406,   41,   41,  401,   46,
      396,  391,  386,   18,   19,   20,   23,   24,   25,   24,
       26,   27,   23,   23,   23,   23,   26,   26,   26,   26,
       26,   27,   46,   52,   52,   57,   57,   62,   62,   67,
       67,   72,   46,   52,   52,   57,   57,   62,   62,   67,
       67,   72,   72,   77,   77,   82,   82,   87,   87,   92,
       92,   97,   72,   77,   77,   82,   82,   87,   87,   92,
       92,   97,   97,  102,  102,  107,  107,  112,  112,  117,

      117,  122,   97,  102,  102,  107,  107,  112,  112,  117,
      117,  122,  122,  127,  127,  132,  132,  137,  137,  142,
      142,  147,  122,  127,  127,  132,  132,  137,  137,  142,
      142,  147,  147,  152,  152,  157,  157,  162,  162,  167,
      167,  172,  147,  152,  152,  157,  157,  162,  162,  167,
      167,  172,  172,  177,  177,  182,  182,  187,  187,  192,
      192,  197,  172,  177,  177,  182,  182,  187,  187,  192,
      192,  197,  197,  202,  202,  207,  207,  212,  212,  217,
      217,  222,  197,  202,  202,  207,  207,  212,  212,  217,
      217,  222,  222,  227,  227,  232,  232,  237,  237,  242,

      242,  247,  222,  227,  227,  232,  232,  237,  237,  242,
      242,  247,  247,  252,  252,  257,  257,  262,  262,  267,
      267,  272,  247,  252,  252,  257,  257,  262,  262,  267,
      267,  272,  272,  277,  277,  282,  282,  287,  287,  292,
      292,  297,  272,  277,  277,  282,  282,  287,  287,  292,
      292,  297,  297,  302,  302,  307,  307,  312,  312,  317,
      317,  322,  297,  302,  302,  307,  307,  312,  312,  317,
      317,  322,  322,  327,  327,  332,  332,  337,  337,  342,
      342,  347,  322,  327,  327,  332,  332,  337,  337,  342,
      342,  347,  347,  352,  352,  357,  357,  362,  362,  367,

      367,  372,  347,  352,  352,  357,  357,  362,  362,  367,
      367,  372,  372,  377,  377,  382,  382,  387,  387,  392,
      392,  397,  372,  377,  377,  382,  382,  387,  387,  392,
      392,  397,  397,  402,  402,  407,  407,  412,  412,  417,
      417,  422,  397,  402,  402,  407,  407,  412,  412,  417,
      417,  422,  422,  427,  427,  381,  376,  371,  366,  361,
      356,  351,  422,  427,  427,   10,   10,   10,   10,   10,
       15,   15,   15,   15,   15,   21,   21,   21,   21,   21,
       28,   28,   28,   30,   30,  346,  341,   30,   33,   33,
      336,   33,   33,   37,   37,  331,  326,   37,   39,   39,

      321,   39,   39,   42,   42,  316,  311,   42,   43,   43,
      306,  301,   43,   44,   44,  296,   44,   44,   47,   47,
      291,  286,   47,   48,   48,   48,  281,   48,   50,   50,
      276,   50,   50,   53,   53,  271,  266,   53,   54,   54,
       54,  261,   54,   55,   55,  256,   55,   55,   58,   58,
      251,  246,   58,   59,   59,   59,  241,   59,   60,   60,
      236,   60,   60,   63,   63,  231,  226,   63,   64,   64,
       64,  221,   64,   65,   65,  216,   65,   65,   68,   68,
      211,  206,   68,   69,   69,   69,  201,   69,   70,   70,
      196,   70,   70,   73,   73,  191,  186,   73,   74,   74,

       74,  181,   74,   75,   75,  176,   75,   75,   78,   78,
      171,  166,   78,   79,   79,   79,  161,   79,   80,   80,
      156,   80,   80,   83,   83,  151,  146,   83,   84,   84,
       84,  141,   84,   85,   85,  136,   85,   85,   88,   88,
      131,  126,   88,   89,   89,   89,  121,   89,   90,   90,
      116,   90,   90,   93,   93,  111,  106,   93,   94,   94,
       94,  101,   94,   95,   95,   96,   95,   95,   98,   98,
       91,   86,   98,   99,   99,   99,   81,   99,  100,  100,
       76,  100,  100,  103,  103,   71,   66,  103,  104,  104,
      104,   61,  104,  105,  105,   56,  105,  105,  108,  108,

       51,   45,  108,  109,  109,  109,   40,  109,  110,  110,
       35,  110,  110,  113,  113,   49,   49,  113,  114,  114,
      114,   49,  114,  115,  115,   49,  115,  115,  118,  118,
       49,   49,  118,  119,  119,  119,   49,  119,  120,  120,
       49,  120,  120,  123,  123,   49,   49,  123,  124,  124,
      124,   49,  124,  125,  125,   49,  125,  125,  128,  128,
       49,   49,  128,  129,  129,  129,   49,  129,  130,  130,
       49,  130,  130,  133,  133,   49,   49,  133,  134,  134,
      134,   49,  134,  135,  135,   49,  135,  135,  138,  138,
       49,   49,  138,  139,  139,  139,   49,  139,  140,  140,

       49,  140,  140,  143,  143,   49,   49,  143,  144,  144,
      144,   49,  144,  145,  145,   49,  145,  145,  148,  148,
       49,   49,  148,  149,  149,  149,   49,  149,  150,  150,
       49,  150,  150,  153,  153,   49,   49,  153,  154,  154,
      154,   49,  154,  155,  155,   49,  155,  155,  158,  158,
       49,   49,  158,  159,  159,  159,   49,  159,  160,  160,
       49,  160,  160,  163,  163,   49,   49,  163,  164,  164,
      164,   49,  164,  165,  165,   49,  165,  165,  168,  168,
       49,   49,  168,  169,  169,  169,   49,  169,  170,  170,
       49,  170,  170,  173,  173,   49,   49,  173,  174,  174,

      174,   49,  174,  175,  175,   49,  175,  175,  178,  178,
       49,   49,  178,  179,  179,  179,   49,  179,  180,  180,
       49,  180,  180,  183,  183,   49,   49,  183,  184,  184,
      184,   49,  184,  185,  185,   49,  185,  185,  188,  188,
       49,   49,  188,  189,  189,  189,   49,  189,  190,  190,
       49,  190,  190,  193,  193,   49,   49,  193,  194,  194,
      194,   49,  194,  195,  195,   49,  195,  195,  198,  198,
       49,   49,  198,  199,  199,  199,   49,  199,  200,  200,
       49,  200,  200,  203,  203,   49,   49,  203,  204,  204,
      204,   49,  204,  205,  205,   49,  205,  205,  208,  208,

       49,   49,  208,  209,  209,  209,   38,  209,  210,  210,
       31,  210,  210,  213,  213,   29,   34,  213,  214,  214,
      214,   32,  214,  215,  215,   32,  215,  215,  218,  218,
       31,   29,  218,  219,  219,  219,  429,  219,  220,  220,
       22,  220,  220,  223,  223,   22,   11,  223,  224,  224,
      224,  429,  224,  225,  225,  429,  225,  225,  228,  228,
      429,  429,  228,  229,  229,  229,  429,  229,  230,  230,
      429,  230,  230,  233,  233,  429,  429,  233,  234,  234,
      234,  429,  234,  235,  235,  429,  235,  235,  238,  238,
      429,  429,  238,  239,  239,  239,  429,  239,  240,  240,

      429,  240,  240,  243,  243,  429,  429,  243,  244,  244,
      244,  429,  244,  245,  245,  429,  245,  245,  248,  248,
      429,  429,  248,  249,  249,  249,  429,  249,  250,  250,
      429,  250,  250,  253,  253,  429,  429,  253,  254,  254,
      254,  429,  254,  255,  255,  429,  255,  255,  258,  258,
      429,  429,  258,  259,  259,  259,  429,  259,  260,  260,
      429,  260,  260,  263,  263,  429,  429,  263,  264,  264,
      264,  429,  264,  265,  265,  429,  265,  265,  268,  268,
      429,  429,  268,  269,  269,  269,  429,  269,  270,  270,
      429,  270,  270,  273,  273,  429,  429,  273,  274,  274,

      274,  429,  274,  275,  275,  429,  275,  275,  278,  278,
      429,  429,  278,  279,  279,  279,  429,  279,  280,  280,
      429,  280,  280,  283,  283,  429,  429,  283,  284,  284,
      284,  429,  284,  285,  285,  429,  285,  285,  288,  288,
      429,  429,  288,  289,  289,  289,  429,  289,  290,  290,
      429,  290,  290,  293,  293,  429,  429,  293,  294,  294,
      294,  429,  294,  295,  295,  429,  295,  295,  298,  298,
      429,  429,  298,  299,  299,  299,  429,  299,  300,  300,
      429,  300,  300,  303,  303,  429,  429,  303,  304,  304,
      304,  429,  304,  305,  305,  429,  305,  305,  308,  308,

      429,  429,  308,  309,  309,  309,  429,  309,  310,  310,
      429,  310,  310,  313,  313,  429,  429,  313,  314,  314,
      314,  429,  314,  315,  315,  429,  315,  315,  318,  318,
      429,  429,  318,  319,  319,  319,  429,  319,  320,  320,
      429,  320,  320,  323,  323,  429,  429,  323,  324,  324,
      324,  429,  324,  325,  325,  429,  325,  325,  328,  328,
      429,  429,  328,  329,  329,  329,  429,  329,  330,  330,
      429,  330,  330,  333,  333,  429,  429,  333,  334,  334,
      334,  429,  334,  335,  335,  429,  335,  335,  338,  338,
      429,  429,  338,  339,  339,  339,  429,  339,  340,  340,

      429,  340,  340,  343,  343,  429,  429,  343,  344,  344,
      344,  429,  344,  345,  345,  429,  345,  345,  348,  348,
      429,  429,  348,  349,  349,  349,  429,  349,  350,  350,
      429,  350,  350,  353,  353,  429,  429,  353,  354,  354,
      354,  429,  354,  355,  355,  429,  355,  355,  358,  358,
      429,  429,  358,  359,  359,  359,  429,  359,  360,  360,
      429,  360,  360,  363,  363,  429,  429,  363,  364,  364,
      364,  429,  364,  365,  365,  429,  365,  365,  368,  368,
      429,  429,  368,  369,  369,  369,  429,  369,  370,  370,
      429,  370,  370,  373,  373,  429,  429,  373,  374,  374,

      374,  429,  374,  375,  375,  429,  375,  375,  378,  378,
      429,  429,  378,  379,  379,  379,  429,  379,  380,  380,
      429,  380,  380,  383,  383,  429,  429,  383,  384,  384,
      384,  429,  384,  385,  385,  429,  385,  385,  388,  388,
      429,  429,  388,  389,  389,  389,  429,  389,  390,  390,
      429,  390,  390,  393,  393,  429,  429,  393,  394,  394,
      394,  429,  394,  395,  395,  429,  395,  395,  398,  398,
      429,  429,  398,  399,  399,  399,  429,  399,  400,  400,
      429,  400,  400,  403,  403,  429,  429,  403,  404,  404,
      404,  429,  404,  405,  405,  429,  405,  405,  408,  408,

      429,  429,  408,  409,  409,  409,  429,  409,  410,  410,
      429,  410,  410,  413,  413,  429,  429,  413,  414,  414,
      414,  429,  414,  415,  415,  429,  415,  415,  418,  418,
      429,  429,  418,  419,  419,  419,  429,  419,  420,  420,
      429,  420,  420,  423,  423,  429,  429,  423,  424,  424,
      424,  429,  424,  425,  425,  429,  425,  425,  428,  428,
      428,  429,  428,    9,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429
    } ;

static yyconst flex_int16_t yy_chk[1581] =
    {   0,
        0,    2,    2,    2,  747,   26,   20,   20,   27,    2,
        3,    3,  743,  739,  735,   26,   35,   36,   27,   40,
        3,    3,    3,    4,    4,  731,   35,   36,  727,   40,
      723,  719,  715,    4,    4,    4,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,   41,   45,   46,   51,   52,   56,   57,   61,
       62,   66,   41,   45,   46,   51,   52,   56,   57,   61,
       62,   66,   67,   71,   72,   76,   77,   81,   82,   86,
       87,   91,   67,   71,   72,   76,   77,   81,   82,   86,
       87,   91,   92,   96,   97,  101,  102,  106,  107,  111,

      112,  116,   92,   96,   97,  101,  102,  106,  107,  111,
      112,  116,  117,  121,  122,  126,  127,  131,  132,  136,
      137,  141,  117,  121,  122,  126,  127,  131,  132,  136,
      137,  141,  142,  146,  147,  151,  152,  156,  157,  161,
      162,  166,  142,  146,  147,  151,  152,  156,  157,  161,
      162,  166,  167,  171,  172,  176,  177,  181,  182,  186,
      187,  191,  167,  171,  172,  176,  177,  181,  182,  186,
      187,  191,  192,  196,  197,  201,  202,  206,  207,  211,
      212,  216,  192,  196,  197,  201,  202,  206,  207,  211,
      212,  216,  217,  221,  222,  226,  227,  231,  232,  236,

      237,  241,  217,  221,  222,  226,  227,  231,  232,  236,
      237,  241,  242,  246,  247,  251,  252,  256,  257,  261,
      262,  266,  242,  246,  247,  251,  252,  256,  257,  261,
      262,  266,  267,  271,  272,  276,  277,  281,  282,  286,
      287,  291,  267,  271,  272,  276,  277,  281,  282,  286,
      287,  291,  292,  296,  297,  301,  302,  306,  307,  311,
      312,  316,  292,  296,  297,  301,  302,  306,  307,  311,
      312,  316,  317,  321,  322,  326,  327,  331,  332,  336,
      337,  341,  317,  321,  322,  326,  327,  331,  332,  336,
      337,  341,  342,  346,  347,  351,  352,  356,  357,  361,

      362,  366,  342,  346,  347,  351,  352,  356,  357,  361,
      362,  366,  367,  371,  372,  376,  377,  381,  382,  386,
      387,  391,  367,  371,  372,  376,  377,  381,  382,  386,
      387,  391,  392,  396,  397,  401,  402,  406,  407,  411,
      412,  416,  392,  396,  397,  401,  402,  406,  407,  411,
      412,  416,  417,  421,  422,  711,  707,  703,  699,  695,
      691,  687,  417,  421,  422,  430,  430,  430,  430,  430,
      431,  431,  431,  431,  431,  432,  432,  432,  432,  432,
      433,  433,  433,  434,  434,  683,  679,  434,  435,  435,
      675,  435,  435,  437,  437,  671,  667,  437,  438,  438,

      663,  438,  438,  440,  440,  659,  655,  440,  441,  441,
      651,  647,  441,  442,  442,  643,  442,  442,  444,  444,
      639,  635,  444,  445,  445,  445,  631,  445,  446,  446,
      627,  446,  446,  448,  448,  623,  619,  448,  449,  449,
      449,  615,  449,  450,  450,  611,  450,  450,  452,  452,
      607,  603,  452,  453,  453,  453,  599,  453,  454,  454,
      595,  454,  454,  456,  456,  591,  587,  456,  457,  457,
      457,  583,  457,  458,  458,  579,  458,  458,  460,  460,
      575,  571,  460,  461,  461,  461,  567,  461,  462,  462,
      563,  462,  462,  464,  464,  559,  555,  464,  465,  465,

      465,  551,  465,  466,  466,  547,  466,  466,  468,  468,
      543,  539,  468,  469,  469,  469,  535,  469,  470,  470,
      531,  470,  470,  472,  472,  527,  523,  472,  473,  473,
      473,  519,  473,  474,  474,  515,  474,  474,  476,  476,
      511,  507,  476,  477,  477,  477,  503,  477,  478,  478,
      499,  478,  478,  480,  480,  495,  491,  480,  481,  481,
      481,  487,  481,  482,  482,  483,  482,  482,  484,  484,
      479,  475,  484,  485,  485,  485,  471,  485,  486,  486,
      467,  486,  486,  488,  488,  463,  459,  488,  489,  489,
      489,  455,  489,  490,  490,  451,  490,  490,  492,  492,

      447,  443,  492,  493,  493,  493,  439,  493,  494,  494,
      436,  494,  494,  496,  496,  428,  424,  496,  497,  497,
      497,  419,  497,  498,  498,  414,  498,  498,  500,  500,
      409,  404,  500,  501,  501,  501,  399,  501,  502,  502,
      394,  502,  502,  504,  504,  389,  384,  504,  505,  505,
      505,  379,  505,  506,  506,  374,  506,  506,  508,  508,
      369,  364,  508,  509,  509,  509,  359,  509,  510,  510,
      354,  510,  510,  512,  512,  349,  344,  512,  513,  513,
      513,  339,  513,  514,  514,  334,  514,  514,  516,  516,
      329,  324,  516,  517,  517,  517,  319,  517,  518,  518,

      314,  518,  518,  520,  520,  309,  304,  520,  521,  521,
      521,  299,  521,  522,  522,  294,  522,  522,  524,  524,
      289,  284,  524,  525,  525,  525,  279,  525,  526,  526,
      274,  526,  526,  528,  528,  269,  264,  528,  529,  529,
      529,  259,  529,  530,  530,  254,  530,  530,  532,  532,
      249,  244,  532,  533,  533,  533,  239,  533,  534,  534,
      234,  534,  534,  536,  536,  229,  224,  536,  537,  537,
      537,  219,  537,  538,  538,  214,  538,  538,  540,  540,
      209,  204,  540,  541,  541,  541,  199,  541,  542,  542,
      194,  542,  542,  544,  544,  189,  184,  544,  545,  545,

      545,  179,  545,  546,  546,  174,  546,  546,  548,  548,
      169,  164,  548,  549,  549,  549,  159,  549,  550,  550,
      154,  550,  550,  552,  552,  149,  144,  552,  553,  553,
      553,  139,  553,  554,  554,  134,  554,  554,  556,  556,
      129,  124,  556,  557,  557,  557,  119,  557,  558,  558,
      114,  558,  558,  560,  560,  109,  104,  560,  561,  561,
      561,   99,  561,  562,  562,   94,  562,  562,  564,  564,
       89,   84,  564,  565,  565,  565,   79,  565,  566,  566,
       74,  566,  566,  568,  568,   69,   64,  568,  569,  569,
      569,   59,  569,  570,  570,   54,  570,  570,  572,  572,

       48,   43,  572,  573,  573,  573,   32,  573,  574,  574,
       31,  574,  574,  576,  576,   28,   25,  576,  577,  577,
      577,   19,  577,  578,  578,   18,  578,  578,  580,  580,
       17,   12,  580,  581,  581,  581,    9,  581,  582,  582,
        6,  582,  582,  584,  584,    5,    1,  584,  585,  585,
      585,    0,  585,  586,  586,    0,  586,  586,  588,  588,
        0,    0,  588,  589,  589,  589,    0,  589,  590,  590,
        0,  590,  590,  592,  592,    0,    0,  592,  593,  593,
      593,    0,  593,  594,  594,    0,  594,  594,  596,  596,
        0,    0,  596,  597,  597,  597,    0,  597,  598,  598,

        0,  598,  598,  600,  600,    0,    0,  600,  601,  601,
      601,    0,  601,  602,  602,    0,  602,  602,  604,  604,
        0,    0,  604,  605,  605,  605,    0,  605,  606,  606,
        0,  606,  606,  608,  608,    0,    0,  608,  609,  609,
      609,    0,  609,  610,  610,    0,  610,  610,  612,  612,
        0,    0,  612,  613,  613,  613,    0,  613,  614,  614,
        0,  614,  614,  616,  616,    0,    0,  616,  617,  617,
      617,    0,  617,  618,  618,    0,  618,  618,  620,  620,
        0,    0,  620,  621,  621,  621,    0,  621,  622,  622,
        0,  622,  622,  624,  624,    0,    0,  624,  625,  625,

      625,    0,  625,  626,  626,    0,  626,  626,  628,  628,
        0,    0,  628,  629,  629,  629,    0,  629,  630,  630,
        0,  630,  630,  632,  632,    0,    0,  632,  633,  633,
      633,    0,  633,  634,  634,    0,  634,  634,  636,  636,
        0,    0,  636,  637,  637,  637,    0,  637,  638,  638,
        0,  638,  638,  640,  640,    0,    0,  640,  641,  641,
      641,    0,  641,  642,  642,    0,  642,  642,  644,  644,
        0,    0,  644,  645,  645,  645,    0,  645,  646,  646,
        0,  646,  646,  648,  648,    0,    0,  648,  649,  649,
      649,    0,  649,  650,  650,    0,  650,  650,  652,  652,

        0,    0,  652,  653,  653,  653,    0,  653,  654,  654,
        0,  654,  654,  656,  656,    0,    0,  656,  657,  657,
      657,    0,  657,  658,  658,    0,  658,  658,  660,  660,
        0,    0,  660,  661,  661,  661,    0,  661,  662,  662,
        0,  662,  662,  664,  664,    0,    0,  664,  665,  665,
      665,    0,  665,  666,  666,    0,  666,  666,  668,  668,
        0,    0,  668,  669,  669,  669,    0,  669,  670,  670,
        0,  670,  670,  672,  672,    0,    0,  672,  673,  673,
      673,    0,  673,  674,  674,    0,  674,  674,  676,  676,
        0,    0,  676,  677,  677,  677,    0,  677,  678,  678,

        0,  678,  678,  680,  680,    0,    0,  680,  681,  681,
      681,    0,  681,  682,  682,    0,  682,  682,  684,  684,
        0,    0,  684,  685,  685,  685,    0,  685,  686,  686,
        0,  686,  686,  688,  688,    0,    0,  688,  689,  689,
      689,    0,  689,  690,  690,    0,  690,  690,  692,  692,
        0,    0,  692,  693,  693,  693,    0,  693,  694,  694,
        0,  694,  694,  696,  696,    0,    0,  696,  697,  697,
      697,    0,  697,  698,  698,    0,  698,  698,  700,  700,
        0,    0,  700,  701,  701,  701,    0,  701,  702,  702,
        0,  702,  702,  704,  704,    0,    0,  704,  705,  705,

      705,    0,  705,  706,  706,    0,  706,  706,  708,  708,
        0,    0,  708,  709,  709,  709,    0,  709,  710,  710,
        0,  710,  710,  712,  712,    0,    0,  712,  713,  713,
      713,    0,  713,  714,  714,    0,  714,  714,  716,  716,
        0,    0,  716,  717,  717,  717,    0,  717,  718,  718,
        0,  718,  718,  720,  720,    0,    0,  720,  721,  721,
      721,    0,  721,  722,  722,    0,  722,  722,  724,  724,
        0,    0,  724,  725,  725,  725,    0,  725,  726,  726,
        0,  726,  726,  728,  728,    0,    0,  728,  729,  729,
      729,    0,  729,  730,  730,    0,  730,  730,  732,  732,

        0,    0,  732,  733,  733,  733,    0,  733,  734,  734,
        0,  734,  734,  736,  736,    0,    0,  736,  737,  737,
      737,    0,  737,  738,  738,    0,  738,  738,  740,  740,
        0,    0,  740,  741,  741,  741,    0,  741,  742,  742,
        0,  742,  742,  744,  744,    0,    0,  744,  745,  745,
      745,    0,  745,  746,  746,    0,  746,  746,  748,  748,
      748,    0,  748,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int fasta_flex_debug;
int fasta_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *fastatext;
#line 1 "sequence/fastal.l"
/* fastal.l - FASTA sequence lexer */
#line 4 "sequence/fastal.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif

#include "sequence/fastay.h"
#define YY_NO_INPUT 1

#line 1047 "sequence/fastal.c"

#define INITIAL 0
#define HEAD 1
#define DESC 2
#define SEQS 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int fastalex_destroy (void );

int fastaget_debug (void );

void fastaset_debug (int debug_flag  );

YY_EXTRA_TYPE fastaget_extra (void );

void fastaset_extra (YY_EXTRA_TYPE user_defined  );

FILE *fastaget_in (void );

void fastaset_in  (FILE * _in_str  );

FILE *fastaget_out (void );

void fastaset_out  (FILE * _out_str  );

int fastaget_leng (void );

char *fastaget_text (void );

int fastaget_lineno (void );

void fastaset_lineno (int _line_number  );

YYSTYPE * fastaget_lval (void );

void fastaset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int fastawrap (void );
#else
extern int fastawrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( fastatext, fastaleng, 1, fastaout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( fastain )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( fastain ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, fastain))==0 && ferror(fastain)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(fastain); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int fastalex \
               (YYSTYPE * yylval_param );

#define YY_DECL int fastalex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after fastatext and fastaleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( fastaleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(fastatext[fastaleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 42 "sequence/fastal.l"


#line 1248 "sequence/fastal.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! fastain )
			fastain = stdin;

		if ( ! fastaout )
			fastaout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			fastaensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				fasta_create_buffer(fastain,YY_BUF_SIZE );
		}

		fasta_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of fastatext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 430 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 429 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 44 "sequence/fastal.l"
; /* Empty lines ignored */
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 46 "sequence/fastal.l"
{ BEGIN HEAD; return SUP; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up fastatext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up fastatext again */
YY_RULE_SETUP
#line 47 "sequence/fastal.l"
{ return ERR; } /* FIXME: Reject NBRF header */
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "sequence/fastal.l"
{ yylval->str = strdup(fastatext); return NAM; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "sequence/fastal.l"
{ BEGIN DESC; return SPC; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 50 "sequence/fastal.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 52 "sequence/fastal.l"
{ yylval->str = strdup(fastatext); return TXT; }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 53 "sequence/fastal.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 55 "sequence/fastal.l"
{ yylval->str = strdup(fastatext); return BAS; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 56 "sequence/fastal.l"
; /* Spaces/Tabs ignored */
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 57 "sequence/fastal.l"
; /* Newlines ignored */
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up fastatext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up fastatext again */
YY_RULE_SETUP
#line 58 "sequence/fastal.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 59 "sequence/fastal.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 60 "sequence/fastal.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HEAD):
case YY_STATE_EOF(DESC):
#line 62 "sequence/fastal.l"
{ return NUL; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 63 "sequence/fastal.l"
{ return ERR; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 64 "sequence/fastal.l"
{ return ERR; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 66 "sequence/fastal.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1433 "sequence/fastal.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed fastain at a new source and called
			 * fastalex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = fastain;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( fastawrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * fastatext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of fastalex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					fastarealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			fastarestart(fastain  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) fastarealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 430 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 430 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 429);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					fastarestart(fastain );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( fastawrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve fastatext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void fastarestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        fastaensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            fasta_create_buffer(fastain,YY_BUF_SIZE );
	}

	fasta_init_buffer(YY_CURRENT_BUFFER,input_file );
	fasta_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void fasta_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		fastapop_buffer_state();
	 *		fastapush_buffer_state(new_buffer);
     */
	fastaensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	fasta_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (fastawrap()) processing, but the only time this flag
	 * is looked at is after fastawrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void fasta_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	fastain = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE fasta_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) fastaalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in fasta_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) fastaalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in fasta_create_buffer()" );

	b->yy_is_our_buffer = 1;

	fasta_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with fasta_create_buffer()
 * 
 */
    void fasta_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		fastafree((void *) b->yy_ch_buf  );

	fastafree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a fastarestart() or at EOF.
 */
    static void fasta_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	fasta_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then fasta_init_buffer was _probably_
     * called from fastarestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void fasta_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		fasta_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void fastapush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	fastaensure_buffer_stack();

	/* This block is copied from fasta_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from fasta_switch_to_buffer. */
	fasta_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void fastapop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	fasta_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		fasta_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void fastaensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)fastaalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in fastaensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)fastarealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in fastaensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE fasta_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) fastaalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in fasta_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	fasta_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to fastalex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       fasta_scan_bytes() instead.
 */
YY_BUFFER_STATE fasta_scan_string (yyconst char * yystr )
{
    
	return fasta_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to fastalex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE fasta_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) fastaalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in fasta_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = fasta_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in fasta_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up fastatext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		fastatext[fastaleng] = (yy_hold_char); \
		(yy_c_buf_p) = fastatext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		fastaleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int fastaget_lineno  (void)
{
        
    return fastalineno;
}

/** Get the input stream.
 * 
 */
FILE *fastaget_in  (void)
{
        return fastain;
}

/** Get the output stream.
 * 
 */
FILE *fastaget_out  (void)
{
        return fastaout;
}

/** Get the length of the current token.
 * 
 */
int fastaget_leng  (void)
{
        return fastaleng;
}

/** Get the current token.
 * 
 */

char *fastaget_text  (void)
{
        return fastatext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void fastaset_lineno (int  _line_number )
{
    
    fastalineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see fasta_switch_to_buffer
 */
void fastaset_in (FILE *  _in_str )
{
        fastain = _in_str ;
}

void fastaset_out (FILE *  _out_str )
{
        fastaout = _out_str ;
}

int fastaget_debug  (void)
{
        return fasta_flex_debug;
}

void fastaset_debug (int  _bdebug )
{
        fasta_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from fastalex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    fastain = stdin;
    fastaout = stdout;
#else
    fastain = (FILE *) 0;
    fastaout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * fastalex_init()
     */
    return 0;
}

/* fastalex_destroy is for both reentrant and non-reentrant scanners. */
int fastalex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		fasta_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		fastapop_buffer_state();
	}

	/* Destroy the stack itself. */
	fastafree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * fastalex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *fastaalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *fastarealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void fastafree (void * ptr )
{
	free( (char *) ptr );	/* see fastarealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 66 "sequence/fastal.l"



